@@ -3,7 +3,7 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use Class::Accessor::Lite (
     ro => [qw/connect_info/],
@@ -103,7 +103,7 @@ sub txn_scope {
 
 sub last_insert_id {
     my $self = shift;
-    $self->dbh->last_insert_id;
+    $self->dbh->last_insert_id(@_);
 }
 
 1;
